@@ -1,14 +1,14 @@
 package Bread::Board::Service::Deferred;
 use Moose ();
 
-our $VERSION   = '0.19';
+our $VERSION   = '0.20';
 our $AUTHORITY = 'cpan:STEVAN';
 
 use overload
     # cover your basic operatins ...
     'bool' => sub { 1 },
     '""'   => sub {
-        $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+        $_[0] = $_[0]->{service}->get;
         if (my $func = overload::Method($_[0], '""')) {
             return $_[0]->$func();
         }
@@ -17,16 +17,16 @@ use overload
     # cover your basic dereferncers
     '%{}' => sub {
         return $_[0] if (caller)[0] eq 'Bread::Board::Service::Deferred';
-        $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+        $_[0] = $_[0]->{service}->get;
         $_[0]
     },
-    '@{}' => sub { $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get); $_[0] },
-    '${}' => sub { $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get); $_[0] },
-    '&{}' => sub { $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get); $_[0] },
-    '*{}' => sub { $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get); $_[0] },
+    '@{}' => sub { $_[0] = $_[0]->{service}->get; $_[0] },
+    '${}' => sub { $_[0] = $_[0]->{service}->get; $_[0] },
+    '&{}' => sub { $_[0] = $_[0]->{service}->get; $_[0] },
+    '*{}' => sub { $_[0] = $_[0]->{service}->get; $_[0] },
     ## and as a last ditch resort ...
     nomethod => sub {
-        $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+        $_[0] = $_[0]->{service}->get;
         return overload::StrVal($_[0]) if $_[3] eq '""' && !overload::Method($_[0], $_[3]);
         if (my $func = overload::Method($_[0], $_[3])) {
             return $_[0]->$func($_[1]);
@@ -47,7 +47,7 @@ sub meta {
         my $class = $_[0]->{service}->class;
         return $class->meta;
     }
-    $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+    $_[0] = $_[0]->{service}->get;
     (shift)->meta;
 }
 
@@ -56,7 +56,7 @@ sub can {
         my $class = $_[0]->{service}->class;
         return $class->can($_[1]);
     }
-    $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+    $_[0] = $_[0]->{service}->get;
     (shift)->can(shift);
 }
 
@@ -66,7 +66,7 @@ sub isa {
         return 1 if $class eq $_[1];
         return $class->isa($_[1]);
     }
-    $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+    $_[0] = $_[0]->{service}->get;
     (shift)->isa(shift);
 }
 
@@ -74,7 +74,7 @@ sub DESTROY { (shift)->{service} = undef }
 
 sub AUTOLOAD {
     my ($subname) = our $AUTOLOAD =~ /([^:]+)$/;
-    $_[0] = (eval { $_[0]->{service}->instance } || $_[0]->{service}->get);
+    $_[0] = $_[0]->{service}->get;
     my $func = $_[0]->can($subname);
     (ref($func) eq 'CODE')
         || Carp::confess "You cannot call '$subname'";
